# Lazi: Lazy Imports Everywhere

A lightweight and extensible way to implement lazy imports globally.

## Usage:

```shell
poetry add lazi
```

```python
"""Automatic lazy loading example.

Install django to run, or change the imports.
"""
import lazi.auto                 # Install import tracking.
import django.test               # Import stuff.
print(lazi.used_count())         # Count loaded modules.
TestCase = django.test.TestCase  # Trigger lazy loading.
print(lazi.used_count())         # More modules were lazy loaded.
```

```shell
python example.py
```

```python
5
211
```

```python
"""Manual lazy loading example.
"""
import lazi.core                        # Import Lazi.
django = lazi.lazy("django")            # Import stuff.
django_test = lazi.lazy("django.test")  # Import more stuff.
print(lazi.used_count())                # Count loaded modules.
TestCase = django_test.TestCase         # Trigger lazy loading.
print(lazi.used_count())                # Module was lazy loaded.
```

```python
1
2
```

## Metadata

Reference for developers: The json dict below contains Python versioning parameters:
- Soft `min` (ignore rev) & hard `max` compatible versions.
- Recommended `use` & creator's environment `dev` versions.

```json
{
  "python": {
    "version": {
      "min": "3.10.11",
      "max": "3.12",
      "use": "3.11",
      "dev": "3.11.2"
    }
  }
}
```